%  get the coordinates of the joints.
%  xyz a matrix with the data in Connections.dat.

xyz = load('Coordinates.dat') ;

%  get the information about which joints the members connect.
%  for example, member 1 connects joints 1 and 4.
%  connect is a matrix with the data in Connections.dat.

connect = load('Connections.dat') ;

members = size(connect,1) ;  % # of members

%  delcare a matix to hold the direction cosine
DC = zeros(33,27);    % matrix of the Direction Cosine

%  calculate the direction cosine of the joints in each member
%  put the direction cosine in the correction location of the matrix

for m = 1:members
    
    %  Get the two joints at the ends of the member.
    joint1 = connect(m,1) ;
    joint2 = connect(m,2) ;
    %  Get the coordinates of points (x1,y1,z1) and (x2,y2,z2)
    Xi = xyz(joint1, 1 ) ;
    Yi = xyz(joint1, 2 ) ;
    Zi = xyz(joint1, 3 ) ;
    Xj = xyz(joint2, 1 ) ;
    Yj = xyz(joint2, 2 ) ;
    Zj = xyz(joint2, 3 ) ;
        
    directioncosineX = (Xj - Xi) / sqrt((Xj - Xi)^2 + (Yj - Yi)^2 + (Zj - Zi)^2);
    directioncosineY = (Yj - Yi) / sqrt((Xj - Xi)^2 + (Yj - Yi)^2 + (Zj - Zi)^2);
    directioncosineZ = (Zj - Zi) / sqrt((Xj - Xi)^2 + (Yj - Yi)^2 + (Zj - Zi)^2);
    
    % insert the value to the right place in the matrix
    
    % filling row x for joint 1
    DC( (1 + (joint1 - 1)*3),  m) = directioncosineX;
    % filling row y for joint 1
    DC( (2 + (joint1 - 1)*3),  m) = directioncosineY;
    % filling row z for joint 1
    DC( (3 + (joint1 - 1)*3),  m) = directioncosineZ;
   
    % filling row x for joint 2
    DC( (1 + (joint2 - 1)*3),  m) = - directioncosineX;
    % filling row y for joint 2
    DC( (2 + (joint2 - 1)*3),  m) = - directioncosineY;
    % filling row z for joint 2
    DC( (3 + (joint2 - 1)*3),  m) = - directioncosineZ;

end % by this the Direction matrix with 33 rows and 27 cols is formed

% now elementing the row y and z for joint #1, and row x and Z for joint
% #2,3

% Formating the final 27 x 27 matrix
DCF = zeros(27,27);

DCF(1,:) = DC(1,:);
DCF(2,:) = DC(5,:);
DCF(3,:) = DC(8,:);
DCF(4:27,:) = DC(10:33,:);

% Forming the load matrix with different given Load at joint 11 (x, y, z)
LOAD = zeros(27,1);

LOAD(25:27,1) = [0.0;0.5;12] ;

% solving the equation
fm = DCF\LOAD;

for j=1:size(fm)
    if (fm(j) > 25) | (fm(j) < -20)
        fprintf(' fm(%d) exceed the capcability of the structure\n', j);
    end
end