function zp = SpringPendulumODE(t, z) 

%  function SpringPendulumODE
%  The purpose of this function is to calculate the derivative of:
%    z = [ radius, theta, radiusdot, thetadot ]
%
%  which we will call zp.  So,
%    zp = [ radiusdot, thetadot, radiusdotdot, thetadotdot ]
%
%  The values of radiusdot and thetadot are given in z, so we really
%  only need to find radiusdotdot and thetadotdot.
%
%  We have to find these using the given differential equations.
%  To put the equations in standard form, we'd solve the two equations
%  simultaneously for these two variables (radiusdotdot and thetadotdot).
%

% These are the global variables.

global  GG LL KK 

% Convert from standard form to meaningful names.

radius    = z(1) ;
theta     = z(2) ;
radiusdot = z(3) ;
thetadot  = z(4) ;

% Compute the dot-dot variables.

radiusdotdot = radius*thetadot^2 - KK*(radius - LL) + GG*cos(theta) ;
thetadotdot  = -2.*radiusdot*thetadot/radius - GG* sin(theta)/radius ;

% Convert back to standard form.
% Note that the variables in zp correspond to the dots of the
% variables in z.

zp = [ radiusdot; thetadot; radiusdotdot; thetadotdot ] ;


