function [t, y] = odeMidpt(diffeq, tn, h, y0)

% input:    diffeq = (string) name of the m-file that evalues the RHS of the
%           ODE written in standard form
%           h = stepsize for advancing the independent variable
%           y = initial condition for the dependent variable

% begin Euler scheme; j = 1 for initial condition

t = (0:h:tn)';      % column vector of elements with spacing h
n = length(t);      % number of elements in the t vector
y = y0*ones(n,1);   % preallocate y for speed
h2 = h/2;           % Avoid repeated evaluation of this constant

% begin midpoint scheme; j = 1 for initial condition
for j = 2:n
    k1 = feval(diffeq, t(j-1), y(j-1));
    k2 = feval(diffeq, t(j-1)+h2, y(j-1)+h2*k1);
    y(j) = y(j-1) + h * k2;
end